@@ -8,7 +8,7 @@ SPVM::MIME::QuotedPrint - Quoted-Printable Encoding/Decoding
 
 =head1 Description
 
-MIME::QuotedPrint class in L<SPVM> has methods for Quoted-Printable encoding/decoding.
+The MIME::QuotedPrint class of L<SPVM> has methods for Quoted-Printable encoding/decoding.
 
 =head1 Usage
 
@@ -21,7 +21,7 @@ MIME::QuotedPrint class in L<SPVM> has methods for Quoted-Printable encoding/dec
 
 =head2 encode_qp
 
-C<static method encode_qp : string ($string : string, $eol : string = undef, $binmode : int = 0);>
+  static method encode_qp : string ($string : string, $eol : string = undef, $binmode : int = 0)
 
 Returns an Quoted-Printable encoded version of the string $string.
 
@@ -50,11 +50,11 @@ that any C<\n> in the original data is encoded as well.
 
 Exceptions:
 
-$string must be defined. Otherwise an exception is thrown.
+The $string must be defined. Otherwise an exception is thrown.
 
 =head2 decode_qp
   
-C<static method decode_qp : string ($string : string);>
+  static method decode_qp : string ($string : string);
 
 Returns the plain text version of the Quoted-Printable string $string.
 
@@ -63,7 +63,7 @@ the $string argument contains C<\r\n> terminated lines.
 
 Exceptions:
 
-$string must be defined. Otherwise an exception is thrown.
+The $string must be defined. Otherwise an exception is thrown.
 
 =head1 Distribution Containing This Class
 
